```bash
> python3 dyck-viz.py -h
usage: dyck-viz.py [-h] [--dim DIM] [--word WORD] [-o]

Rendering of Dyck promotions.

optional arguments:
  -h, --help   show this help message and exit
  --dim DIM    symbols, size
  --word WORD  single word to render
  -o           enable output
```
